import corsMiddleware from './corsMiddleware';

const okMiddleWare = event =>
  Promise.resolve({
    statusCode: 200,
    body: `OK`
  });

test('corsMiddleware with no CORS headers leaves response unchanged', () => {
  const event = {
    headers: {
      origin: 'https://www.seek.com.au'
    }
  };
  return corsMiddleware()(okMiddleWare)(event).then(response => {
    expect(response.body).toEqual('OK');
  });
});

test('corsMiddleware preflight', () => {
  const event = {
    headers: {
      origin: 'https://www.seek.com.au'
    },
    httpMethod: 'OPTIONS'
  };
  return corsMiddleware()(okMiddleWare)(event).then(response => {
    expect(response).toEqual({
      headers: {
        'Access-Control-Allow-Headers':
          'Content-Type,X-Amz-Date,Authorization,X-Api-Key,X-Amz-Security-Token',
        'Access-Control-Allow-Methods': 'GET,POST,PUT',
        'Access-Control-Allow-Origin': 'https://www.seek.com.au',
        'Access-Control-Max-Age': 86400,
      },
      statusCode: 200
    });
  });
});

test('corsMiddleware gives normal response with access-control headers', () => {
  const event = {
    headers: {
      origin: 'https://www.seek.com.au'
    },
    httpMethod: 'GET'
  };
  return corsMiddleware()(okMiddleWare)(event).then(response => {
    expect(response).toEqual({
      body: 'OK',
      headers: {
        'Access-Control-Allow-Credentials': true,
        'Access-Control-Allow-Origin': 'https://www.seek.com.au'
      },
      statusCode: 200
    });
  });
});
