import get from 'lodash/get';
import pickBy from 'lodash/pickBy';
import { defaultConfig, isHostAllowed } from './corsConfig';

const pickTruthyValues = obj => pickBy(obj, value => value);

const getCorsPreflightResponse = (config, host) => ({
  headers: pickTruthyValues({
    'Access-Control-Allow-Origin': host,
    'Access-Control-Allow-Methods': config.allowMethods,
    'Access-Control-Allow-Headers': config.allowHeaders,
    'Access-Control-Max-Age': config.maxAge
  }),
  statusCode: 200
});

const corsResponseMiddleware = (config = defaultConfig) => next => event => {
  const host = get(event, 'headers.origin');
  if (event.httpMethod === 'OPTIONS' && isHostAllowed(config, host)) {
    return Promise.resolve(getCorsPreflightResponse(config, host));
  }
  return next(event);
};

export default corsResponseMiddleware;
