import get from 'lodash/get';
import pickBy from 'lodash/pickBy';
import { defaultConfig, isHostAllowed } from './corsConfig';

const pickTruthyValues = obj => pickBy(obj, value => value);

const getCorsResponseHeaders = (response, host, config) => pickTruthyValues({
  'Access-Control-Allow-Origin': host,
  'Access-Control-Allow-Credentials': true,
  'Access-Control-Expose-Headers': config.exposeHeaders,
  ...(response.headers || {})
});

const corsResponseMiddleware = (config = defaultConfig) => next => event => {
  const host = get(event, 'headers.origin');
  if (!isHostAllowed(config, host)) {
    return next(event);
  }
  return next(event).then(response => ({
    ...response,
    headers: getCorsResponseHeaders(response, host, config)
  }));
};

export default corsResponseMiddleware;
