import corsResponseMiddleware from './corsResponseMiddleware';

test('corsResponseMiddleware www.seek.com.au', () => {
  const event = {
    headers: {
      origin: 'https://www.seek.com.au'
    }
  };
  return corsResponseMiddleware()(e => Promise.resolve(e))(event).then(
    response => {
      expect(response).toEqual({
        headers: {
          'Access-Control-Allow-Credentials': true,
          'Access-Control-Allow-Origin': 'https://www.seek.com.au',
          origin: 'https://www.seek.com.au'
        }
      });
    }
  );
});

test('corsResponseMiddleware empty', () => {
  const event = {};
  return corsResponseMiddleware()(e => Promise.resolve(e))(event).then(
    response => {
      expect(response).toEqual({});
    }
  );
});

test('corsResponseMiddleware hacker', () => {
  const event = {
    headers: {
      origin: 'tcp://hacker.com'
    }
  };
  return corsResponseMiddleware()(e => Promise.resolve(e))(event).then(
    response => {
      expect(response).toEqual(event);
    }
  );
});

test('corsResponseMiddleware staging', () => {
  const event = {
    headers: {
      origin: 'https://chalice-branch-create.discover.staging.cloud.seek.com.au'
    }
  };
  return corsResponseMiddleware()(e => Promise.resolve(e))(event).then(
    response => {
      expect(response).toEqual({
        headers: {
          'Access-Control-Allow-Credentials': true,
          'Access-Control-Allow-Origin':
            'https://chalice-branch-create.discover.staging.cloud.seek.com.au',
          origin:
            'https://chalice-branch-create.discover.staging.cloud.seek.com.au'
        }
      });
    }
  );
});

test('corsResponseMiddleware dev', () => {
  const event = {
    headers: {
      origin: 'https://dev.seek.com.au'
    }
  };
  return corsResponseMiddleware()(e => Promise.resolve(e))(event).then(
    response => {
      expect(response).toEqual({
        headers: {
          'Access-Control-Allow-Credentials': true,
          'Access-Control-Allow-Origin': 'https://dev.seek.com.au',
          origin: 'https://dev.seek.com.au'
        }
      });
    }
  );
});
